#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use strict;
use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use Encode;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Web;
use Vhffs::Acl;
use Vhffs::Constants;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $template;

my $cgi          = $panel->{'cgi'};
my $vhffs        = $panel->{'vhffs'};
my $maintemplate = $panel->{'template'};
my $user         = $panel->{'user'};

my $subject      = Encode::decode_utf8( $cgi->param('SUBJECT') );
my $body         = Encode::decode_utf8( $cgi->param('BODY') );

my $templatedir  = $vhffs->get_config->get_templatedir;

$template        = new HTML::Template( filename => $templatedir."/panel/admin/misc/moderation_applied.tmpl" );
my $message;
#Use is not allowed to see this page, only MODERATOR and ADMIN
if( $user->is_admin != 1 ) 
{
	$message = gettext("You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined $body ) || ( ! defined $subject ) )
{
	$message = gettext("CGI Error !");
	$template->param( MESSAGE => $message );
}
else
{
	use Vhffs::Mailings;
	if( Vhffs::Mailings::add_mailing( $vhffs , $subject , $body ) == 1 )
	{
		$template->param( MESSAGE  => gettext("Mailing successfully added") );
	}
	else
	{
		$template->param( MESSAGE  => gettext("Error !") );
	}
}

$panel->set_refresh_url( "/admin/broadcast.pl" );
$panel->build( $template );
$panel->display;
