#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use DateTime;
use DateTime::Locale;
use strict;


use lib '/usr/share/vhffs/api';
use Vhffs::Panel::Main;
use Vhffs::Panel::Admin;
use Vhffs::Panel::Template;
use Vhffs::Tag::Category;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

$panel->check_modo;

my $cgi = $panel->{cgi};

if(defined $cgi->param('delete_category_submit')) {
	if(delete_category()) {
		$panel->add_info( gettext('Category deleted') );
	} else {
		$panel->add_error( gettext('Unable to delete category') );
	}
}

my $templatedir = $panel->{templatedir};

my $template = new Vhffs::Panel::Template(filename => $templatedir.'/panel/admin/tag/category/list.tmpl', die_on_bad_params => 0 );

$panel->set_title(gettext('Tag categories'));

my $categories =  Vhffs::Tag::Category::get_all($panel->{vhffs});
# We should really drop HTML::Template....
my $user = $panel->{user};
my $loc = DateTime::Locale->load($user->get_lang);
foreach(@$categories) {
	my $dt = DateTime->from_epoch( epoch => $_->{updated}, locale => $user->get_lang);
	$_->{updated} = $dt->strftime($loc->medium_date_format().' '.$loc->long_time_format());
	$_->{updater_name} = $_->get_updater()->get_username();
	$_->{visibility_string} = Vhffs::Tag::Category::get_visibility_string($_->{visibility});
}

$template->param( 'CATEGORIES' => $categories );

$panel->build( $template );
$panel->display;

sub delete_category {
	my $category_id = $cgi->param('category_id');
	my $category = Vhffs::Tag::Category::get_by_category_id($panel->{vhffs}, $category_id);
	if(!defined $category) {
		return 0;
	}
	
	return $category->delete();
}
