#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use strict;


use lib '/usr/share/vhffs/api';
use Vhffs::Panel::Admin;
use Vhffs::Panel::Main;
use Vhffs::Panel::Template;
use Vhffs::Tag;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

$panel->check_modo;

my $cgi = $panel->{cgi};
my $tag;
my $template;
my $templatedir = $panel->{templatedir};
my $vhffs = $panel->{vhffs};
my $user = $panel->{user};

if(!defined $cgi->param('tag_id')) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('CGI Error!') );
} elsif(!defined($tag = Vhffs::Tag::get_by_tag_id($panel->{vhffs}, $cgi->param('tag_id')))) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('Tag not found!') );
} else {
	if(defined $cgi->param('update_tag_submit')) {
		if(update()) {
			$panel->add_info( gettext('Tag successfully updated') );
		} else {
			$panel->add_error( gettext('Unable to update tag') )
		}
	}
	
	$template = new Vhffs::Panel::Template(filename => $templatedir.'/panel/admin/tag/edit.tmpl', die_on_bad_params => 0);
	
	$panel->set_title(gettext('Update Tag'));
	
	$template->param( LABEL_VALUE => $tag->{label} );
	$template->param( DESCRIPTION_VALUE => $tag->{description} );
	$template->param( CATEGORY_ID_VALUE => $tag->{category_id} );
	$template->param( CATEGORIES => Vhffs::Tag::Category::get_all($vhffs) );
	$template->param( TAG_ID => $tag->{tag_id} );
	
}
$panel->build( $template );
$panel->display;


sub update {
	my $tag_id = $cgi->param('tag_id');
	my $label = $cgi->param('label');
	my $description = $cgi->param('description');
	my $category_id = $cgi->param('category_id');
	
	if(!(defined $tag_id && defined $label && defined $description && defined $category_id)) {
		$panel->add_error( gettext('CGI error') );
		return 0;
	}
	
	if($label =~ /^\s*$/) {
		$panel->add_error( gettext('You have to enter a label') );
	}
	
	if($description =~ /^\s*$/) {
		$panel->add_error( gettext('You have to enter a description') );
	}
	
	if($category_id !~ /^\d+$/) {
		$panel->add_error( gettext('Invalid category') );
	}
	
	if($panel->has_errors()) {
		return 0;
	}
	
	
	$tag->{label} = $label;
	$tag->{description} = $description;
	$tag->{category_id} = $category_id;
	$tag->{updated} = time();
	$tag->{updater_id} = $user->get_uid;
	return $tag->save();
}
