#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Object;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $templatedir = $panel->{'templatedir'};

my $repo_name = $cgi->param('name');
my $template;

my $cvs;

unless( defined $repo_name ) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'CGI Error !' ) );
} elsif( !defined($cvs = Vhffs::Services::Cvs::get_by_cvsroot($vhffs, $repo_name) ) ) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'Cannot get informations on this object' ) );
} elsif( ! $user->can_view($cvs) ) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' ) );
} else {

	if( defined $cgi->param('cvs_public_submit') ) {
		unless( $user->can_modify($cvs) ) {
			$panel->add_error( gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' ) );
		} elsif( !defined($cgi->param('public')) ) {
			$panel->add_error( gettext("CGI Error !") );
		} else {
			$cvs->set_public($cgi->param('public'));
			$cvs->set_status(Vhffs::Constants::WAITING_FOR_MODIFICATION);
			if($cvs->commit > 0) {
				$panel->add_info(gettext("CVS repository updated"));
			} else {
				$panel->add_error(gettext("An error occured during CVS repository update"));
			}
		}
	}

	$template = new HTML::Template( filename => $templatedir."/panel/cvs/prefs.tmpl" );

	$panel->set_title( gettext('Admin CVS Repository') );

	$template->param( TEXT_REPONAME => $cvs->get_cvsroot );
	$template->param( VALUE_OID => $cvs->get_oid );
	$template->param( TEXT_PUBLIC => gettext("Is this CVS repository public ??") );
	$template->param( PUBLIC_YES => gettext("Yes") );
	$template->param( PUBLIC_NO => gettext("No") );
	$template->param( TEXT_SEND => gettext("Modify") );
	$template->param( TEXT_DELETE_CVS => gettext("Delete this project") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. This cvs repository will be DESTROYED.") );
	$template->param( ASK_DELETE_CVS => gettext("Are you SURE you want DELETE this cvs repository ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );

	$template->param( TEXT_ACL_ADMIN => "Admin Rights on this object (ACL)" );
	$template->param( EXPLAIN_ADMIN_ACL => "You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it." );
	$template->param( ADMIN_ACL => "Ok, go to ACL admin" );

	$template->param( PUBLIC => $cvs->is_public );

	my $adminpart = Vhffs::Panel::Object::admin_part( $panel, $cvs );
	$template->param( ADMIN_PART => $adminpart->output ) if( $adminpart );
}

$panel->build( $template );
$panel->display;
