#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Web;
use Vhffs::Acl;
use Vhffs::Constants;
use Vhffs::Functions;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $oid = $cgi->param("OID");

$oid = $cgi->param("oid") if( ! defined $oid );

my $template;

my $object;
my $ok = 1;
my $title;

my $message;

$object = Vhffs::Object::get_by_oid( $vhffs , $oid );


my $templatesdir = $vhffs->get_config->get_templatedir;


if( ! defined $oid ) {
	$template = new HTML::Template( filename => $templatesdir."/panel/misc/simplemsg.tmpl" );
	$message = gettext( "CGI Error !");
	$template->param( MESSAGE => $message );
} elsif( !defined $object ) {

	$template = new HTML::Template( filename => $templatesdir."/panel/misc/simplemsg.tmpl" );
	$message = gettext("Cannot get information on this object");
	$template->param( MESSAGE => $message );

} elsif( !$user->can_view($object) ) {
	$template = new HTML::Template( filename => $templatesdir."/panel/misc/simplemsg.tmpl" );
	$message = gettext("You're not allowed to view this object's ACL");
	$template->param( MESSAGE => $message );
} else {
	$template = new HTML::Template( filename => $templatesdir."/panel/misc/history.tmpl" );
    $panel->set_title( gettext("History") );

	my $subtemplate;
	my $history = $object->get_history;
	my $string;
	my $date;

    unless(@{$history}) {
        $template->param( HISTORY_PART => gettext('No event about this object') );
    } else {
        my $output = '';
        my $history_tmpl = new HTML::Template( filename => $templatesdir.'/panel/misc/history_part.tmpl' );
        use DateTime;
        use DateTime::Locale;
        my $loc = DateTime::Locale->load($user->get_lang);
        foreach (@{$history}) {
            my $dt = DateTime->from_epoch( epoch => $_->{date}, locale => $user->get_lang);
            $history_tmpl->param( DATE => $dt->strftime($loc->medium_date_format().' '.$loc->long_time_format()));
            $history_tmpl->param( EVENT => $_->{message} );
            $history_tmpl->param( MODERATOR => $user->is_admin || $user->is_moderator );
            $history_tmpl->param( SOURCE => $_->{source} );
            $output .= $history_tmpl->output;
        }
        $template->param( HISTORY_PART => $output );
    }

}

$panel->build( $template );
$panel->display;
