#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use Encode;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Panel::Main;
use Vhffs::Functions;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{vhffs};
my $templatedir = $panel->{templatedir};
my $cgi = $panel->{cgi};
my $user = $panel->{user};
my $group = Vhffs::Group::get_by_groupname( $vhffs , $cgi->param('group') );

unless( defined $group && $user->can_modify( $group ) ) {
	my $template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this (ACL rights)' ) );

	$panel->build( $template );
	$panel->display;
}
else  {
	my $submitted = defined($cgi->param('mail_submit'));
	my $domain = '';
	my $description = '';

	if( $submitted ) {
		$domain = $cgi->param('domain');
		$description = Encode::decode_utf8( $cgi->param('description') );
		unless( defined $domain  &&  defined $description ) {
			$panel->add_error( gettext('CGI Error !') );
		} elsif( !Vhffs::Functions::check_domain_name($domain) ) {
			$panel->add_error( gettext('Invalid domain name') );
		} elsif( $description =~ /^\s*$/ ) {
			$panel->add_error( gettext('You must enter a description') );
		} elsif( defined(Vhffs::Panel::Mail::create_mail( $vhffs , $domain , $description, $user , $group )) ) {
			my $url = '/group/view.pl?group='.$group->get_groupname.'&msg='.gettext('Mail domain successfully created !');
			$panel->redirect($url);
		} else {
			$panel->add_error( gettext('An error occured while creating the mail area') );
		}
	}

	if( !$submitted || $panel->has_errors() ) {
		my $template = new HTML::Template( filename => $templatedir.'/panel/mail/create.tmpl' );

		$panel->set_title( gettext('Create a mail space') );
		$template->param( DOMAIN_TEXT => gettext('Domain') );
		$template->param( DOMAIN_VALUE => $domain );
		$template->param( GROUP_NAME => gettext('Group owning this mail domain') );

		$template->param( GROUP => $group->get_groupname );
		$template->param( SEND => gettext('Send') );
		$template->param( DESCRIPTION_TEXT => gettext('Tell us for what purpose you want to create this mail domain') );
		$template->param( DESCRIPTION_VALUE => CGI::escapeHTML($description) );

		$panel->build( $template );
		$panel->display;
	}
}
