#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;
use Vhffs::Constants;
use Vhffs::Object;
use Vhffs::ObjectFactory;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{vhffs};
my $templatedir = $panel->{templatedir};
my $user = $panel->{user};
my $cgi = $panel->{cgi};

my $oid = $cgi->param('oid');
$panel->add_error( gettext('CGI Error !') ) unless defined $oid;

my $object;
if( defined $oid )  {
	$object = Vhffs::ObjectFactory::fetch_object( $vhffs , $oid );
	$panel->add_error( gettext('This object does not exist') ) unless defined $object;
}

if( defined $object  &&  $object->get_status != Vhffs::Constants::VALIDATION_REFUSED )  {
	$panel->add_error( gettext('This object is not in refused state') );
	undef $object;
}

if( defined $object  &&  $object->get_owner_uid != $user->get_uid )  {
	$panel->add_error( gettext('You are not allowed to do it, you don\'t own this object') );
	undef $object;
}

if( $object ) {

	my $url;

	if( $object->get_type == Vhffs::Constants::TYPE_GROUP ) {
		$url = '/group/index.pl?msg='.gettext('This object has been deleted');
	}
	else {
		my $group = Vhffs::Group::get_by_gid( $vhffs , $object->get_owner_gid );
		$url = '/group/view.pl?group='.$group->get_groupname.'&msg='.gettext('This object has been deleted');
	}

	if( $object->delete )  {
		$panel->redirect( $url );
	}
	else {
		$panel->add_error( gettext('An error occured while deleting this object.') );
	}
}


if( $panel->has_errors ) {

	$panel->set_title( gettext('Object deletion') );
	$panel->build;
	$panel->display;
}
