#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Group;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;
use Vhffs::Services::Web;
use Vhffs::Acl;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $message;
my $owner = $cgi->param("PROJECT_OWNER");

my $delete = $cgi->param("DELETE");

my $templatedir = $vhffs->get_config->get_templatedir;

my $userp;
my $username = $cgi->param('name');
if( defined $username ) {
	$userp = Vhffs::User::get_by_username( $vhffs, $username );
} else {
	$userp = $user;
}

#We test if the owner exist

# We make sure the current user is allowed to delete the specified user
if( !$user->can_delete( $userp ) )
{
	$message = gettext("You\'re not allowed to delete this user");
}
else
{
	if( $delete == 1 )
	{
		if( $userp->have_activegroups )
		{
			$message = gettext("This user is always in a group");
		}
		else
		{
			$userp->set_status( Vhffs::Constants::TO_DELETE );
			if( $userp->commit < 0 )
			{
				$message = gettext("An error occured while applying changes. This user will NOT be deleted");
			}
			else
			{
				$message = gettext("This user will BE DELETED");
			}
		}
	}
	else
	{
			$message = gettext("This user will NOT be DELETED");
		
	}
}


my $template = new HTML::Template( filename => $templatedir."/panel/misc/simplemsg.tmpl" );
$template->param( MESSAGE => $message );

$panel->set_refresh_url( '/panel.pl' );
$panel->build( $template );
$panel->display;
